@@ -1,5 +1,5 @@
 /* md5pwd.c --- Find passwords in UoW imapd MD5 type password files.
- * Copyright (C) 2002, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2004, 2005  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -13,9 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * License along with GNU SASL Library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License License along with GNU SASL Library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -68,10 +69,15 @@ gsasl_simple_getpass (const char *filename, const char *username, char **key)
 	    {
 	      *key = malloc (strlen (line) - userlen);
 	      if (!*key)
-		return GSASL_MALLOC_ERROR;
+		{
+		  free (line);
+		  return GSASL_MALLOC_ERROR;
+		}
 
 	      strcpy (*key, line + userlen + 1);
 
+	      free (line);
+
 	      fclose (fh);
 
 	      return GSASL_OK;
@@ -81,5 +87,8 @@ gsasl_simple_getpass (const char *filename, const char *username, char **key)
       fclose (fh);
     }
 
+  if (line)
+    free (line);
+
   return GSASL_AUTHENTICATION_ERROR;
 }
